@@ -6,7 +6,7 @@
 
 module RbConfig
   RUBY_VERSION.start_with?("2.3.") or
-    raise "ruby lib version (2.3.3) doesn't match executable version (#{RUBY_VERSION})"
+    raise "ruby lib version (2.3.4) doesn't match executable version (#{RUBY_VERSION})"
 
   TOPDIR = File.dirname(__FILE__).chomp!("/lib/ruby/2.3.0/armv5tel-linux-eabi")
   DESTDIR = '' unless defined? DESTDIR
@@ -15,7 +15,7 @@ module RbConfig
   CONFIG["MAJOR"] = "2"
   CONFIG["MINOR"] = "3"
   CONFIG["TEENY"] = "0"
-  CONFIG["PATCHLEVEL"] = "222"
+  CONFIG["PATCHLEVEL"] = "301"
   CONFIG["INSTALL"] = '/usr/bin/install -c'
   CONFIG["EXEEXT"] = ""
   CONFIG["prefix"] = (TOPDIR || DESTDIR + "/opt/ruby2.3")
@@ -38,7 +38,7 @@ module RbConfig
   CONFIG["RUBY_SEARCH_PATH"] = ""
   CONFIG["UNIVERSAL_INTS"] = ""
   CONFIG["UNIVERSAL_ARCHNAMES"] = ""
-  CONFIG["configure_args"] = " '--prefix=/opt/ruby2.3' '--program-suffix=-2.3' '--sysconfdir=/etc' '--localstatedir=/var' '--sharedstatedir=/var/lib' '--libexecdir=/usr/lib/ruby' '--enable-shared' '--disable-rpath' '--with-dbm-type=gdbm_compat' 'CFLAGS=-march=armv5te -O2 -pipe -fstack-protector --param=ssp-buffer-size=4' 'LDFLAGS=-Wl,-O1,--sort-common,--as-needed,-z,relro' 'CPPFLAGS=-D_FORTIFY_SOURCE=2' 'CXXFLAGS=-march=armv5te -O2 -pipe -fstack-protector --param=ssp-buffer-size=4'"
+  CONFIG["configure_args"] = " '--prefix=/opt/ruby2.3' '--program-suffix=-2.3' '--sysconfdir=/etc' '--localstatedir=/var' '--sharedstatedir=/var/lib' '--libexecdir=/usr/lib/ruby' '--enable-shared' '--disable-rpath' '--with-dbm-type=gdbm_compat' 'CFLAGS=-march=armv5te -O2 -pipe -fstack-protector-strong --param=ssp-buffer-size=4' 'LDFLAGS=-Wl,-O1,--sort-common,--as-needed,-z,relro' 'CPPFLAGS=-D_FORTIFY_SOURCE=2' 'CXXFLAGS=-march=armv5te -O2 -pipe -fstack-protector-strong --param=ssp-buffer-size=4'"
   CONFIG["CONFIGURE"] = "configure"
   CONFIG["vendorarchdir"] = "$(vendorlibdir)/$(sitearch)"
   CONFIG["vendorlibdir"] = "$(vendordir)/$(ruby_version)"
@@ -161,11 +161,11 @@ module RbConfig
   CONFIG["EGREP"] = "/usr/bin/grep -E"
   CONFIG["GREP"] = "/usr/bin/grep"
   CONFIG["CPP"] = "$(CC) -E"
-  CONFIG["CXXFLAGS"] = "-march=armv5te -O2 -pipe -fstack-protector --param=ssp-buffer-size=4"
+  CONFIG["CXXFLAGS"] = "-march=armv5te -O2 -pipe -fstack-protector-strong --param=ssp-buffer-size=4"
   CONFIG["OBJEXT"] = "o"
   CONFIG["CPPFLAGS"] = "-D_FORTIFY_SOURCE=2 $(DEFS) $(cppflags)"
   CONFIG["LDFLAGS"] = "-L. -Wl,-O1,--sort-common,--as-needed,-z,relro -fstack-protector -rdynamic -Wl,-export-dynamic"
-  CONFIG["CFLAGS"] = "-march=armv5te -O2 -pipe -fstack-protector --param=ssp-buffer-size=4 -fPIC"
+  CONFIG["CFLAGS"] = "-march=armv5te -O2 -pipe -fstack-protector-strong --param=ssp-buffer-size=4 -fPIC"
   CONFIG["CXX"] = "g++"
   CONFIG["CC"] = "gcc"
   CONFIG["NACL_LIB_PATH"] = ""
@@ -187,7 +187,7 @@ module RbConfig
   CONFIG["build_vendor"] = "unknown"
   CONFIG["build_cpu"] = "armv5tel"
   CONFIG["build"] = "armv5tel-unknown-linux-gnueabi"
-  CONFIG["RUBY_PROGRAM_VERSION"] = "2.3.3"
+  CONFIG["RUBY_PROGRAM_VERSION"] = "2.3.4"
   CONFIG["cxxflags"] = " $(optflags) $(debugflags) $(warnflags)"
   CONFIG["cppflags"] = ""
   CONFIG["cflags"] = " $(optflags) $(debugflags) $(warnflags)"
